@@ -4,11 +4,11 @@ A hack to extract private types out from :mod:`argparse`
 import argparse
 
 __parser = argparse.ArgumentParser()
-__store = __parser.add_argument('-a', action='store')
-__store_const = __parser.add_argument('-b', action='store_const', const='b')
-__store_true = __parser.add_argument('-c', action='store_true')
-__store_false = __parser.add_argument('-d', action='store_false')
-__version_command = __parser.add_argument('-V', action='version', version='1')
+__store = __parser.add_argument("-a", action="store")
+__store_const = __parser.add_argument("-b", action="store_const", const="b")
+__store_true = __parser.add_argument("-c", action="store_true")
+__store_false = __parser.add_argument("-d", action="store_false")
+__version_command = __parser.add_argument("-V", action="version", version="1")
 
 StoreAction = type(__store)
 StoreConstAction = type(__store_const)
