@@ -12,21 +12,22 @@ class Placeholders:
 
     https://github.com/FNNDSC/ChRIS_store/blob/0295268f7cd65593a259a7a00b83eac8ae876c33/store_backend/plugins/serializers.py#L404-L407
     """
+
     INT = -1
     FLOAT = 0.0
-    STR = ''
+    STR = ""
     BOOL = False
 
     _logger = logging.getLogger(__name__)
 
     @classmethod
     def get_for(cls, t: ParameterType) -> Union[int, float, str, bool]:
-        cls.__check_not(t, 'path')
-        cls.__check_not(t, 'unextpath')
-        cls._logger.warning('optional parameter does not specify a default')
+        cls.__check_not(t, "path")
+        cls.__check_not(t, "unextpath")
+        cls._logger.warning("optional parameter does not specify a default")
         return cls.__dict__[t.upper()]
 
     @staticmethod
     def __check_not(t: ParameterType, s: str):
         if t == s:
-            raise ValueError(f'parameter with {t} type may not be optional')
+            raise ValueError(f"parameter with {t} type may not be optional")
